summaryrefslogtreecommitdiffstats
path: root/mlir/lib/Transforms/StripDebugInfo.cpp
diff options
context:
space:
mode:
authorRiver Riddle <riverriddle@google.com>2019-03-27 14:02:02 -0700
committerjpienaar <jpienaar@google.com>2019-03-29 17:47:26 -0700
commit99b87c9707b389183de33961f81d4b2730b033c8 (patch)
tree028b9ca91407a819726ed7a3aa8a07f975f4de5c /mlir/lib/Transforms/StripDebugInfo.cpp
parent3518122e86c864276da532c15610c86bc57c0a56 (diff)
downloadbcm5719-llvm-99b87c9707b389183de33961f81d4b2730b033c8.tar.gz
bcm5719-llvm-99b87c9707b389183de33961f81d4b2730b033c8.zip
Replace usages of Instruction with Operation in the Transforms/ directory.
PiperOrigin-RevId: 240636130
Diffstat (limited to 'mlir/lib/Transforms/StripDebugInfo.cpp')
-rw-r--r--mlir/lib/Transforms/StripDebugInfo.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/mlir/lib/Transforms/StripDebugInfo.cpp b/mlir/lib/Transforms/StripDebugInfo.cpp
index 9d6b7a0ba27..1691976a05a 100644
--- a/mlir/lib/Transforms/StripDebugInfo.cpp
+++ b/mlir/lib/Transforms/StripDebugInfo.cpp
@@ -32,9 +32,9 @@ void StripDebugInfo::runOnFunction() {
Function &func = getFunction();
UnknownLoc unknownLoc = UnknownLoc::get(&getContext());
// Strip the debug info from the function and its instructions.
func.setLoc(unknownLoc);
- func.walk([&](Instruction *inst) { inst->setLoc(unknownLoc); });
+ func.walk([&](Operation *op) { op->setLoc(unknownLoc); });
}
/// Creates a pass to strip debug information from a function.
@@ -43,4 +43,4 @@ FunctionPassBase *mlir::createStripDebugInfoPass() {
}
static PassRegistration<StripDebugInfo>
- pass("strip-debuginfo", "Strip debug info from functions and instructions");
+ pass("strip-debuginfo", "Strip debug info from functions and operations");
OpenPOWER on IntegriCloud
@@ -32,9 +32,9 @@ void StripDebugInfo::runOnFunction() {
Function &func = getFunction();
UnknownLoc unknownLoc = UnknownLoc::get(&getContext());
- // Strip the debug info from the function and its instructions.
+ // Strip the debug info from the function and its operations.
func.setLoc(unknownLoc);